@@ -2,4 +2,4 @@ from os.path import dirname, join
 
 
 DIR_RES = join(dirname(__file__), "res")
-FILE_SETTING = "setting.glm.py"
+FILE_SETTING = "glm_setting.py"
